# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.amz_products_analyzer_from_mongo import AmzProductsAnalyzerFromMongo
from em_tasks.store.models import *

from em_celery import (
  logger,
  init_db,
  get_config,
  get_amz_offer_filter_config,
  get_offer_service_config,
  get_product_service,
  get_mongo
)

@click.command("Analyze Amazon products.")
@click.option("-m", "--marketplace", required=True, type=str, default="us", help="Amazon marketplace.")
@click.option("-o", "--output_path", required=True, type=str, help="Output file path")
def analyze_products(output_path, marketplace="us"):
  init_db()

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  marketplace = marketplace.lower()
  mongo_client = get_mongo()


  asins = set()
  count = 30000
  for doc in mongo_client.client[f"amazon_{marketplace}"].asins_sended.find({"type": "catelog"}, batch_size=4000):
      asins.add(doc["asin"])
      count -= 1
      if count < 0:
          break
  with open(output_path, "w") as file:
      for asin in asins:
        file.write(asin + "\n")



if __name__ == "__main__":
  analyze_products()
